@@ -1,13 +1,14 @@
 import asyncio
 
-from ..utils import ChannelHolder, get_server_address_and_port, Channel
+from pyfsftpserver.base.utils import IpEndpoint, ChannelHolder, get_server_endpoint, Channel
 
 
 class DataProtocol:
-    def __init__(self, host, port=None):
+    def __init__(self, ctx):
         self.server = None
-        self.host = host
-        self.port = port
+        data_endpoint_config: IpEndpoint = ctx['data_endpoint_config']
+        self.host = data_endpoint_config.address
+        self.port = data_endpoint_config.port
         self.channel_holder = ChannelHolder()
 
     def close(self):
@@ -18,7 +19,7 @@ class DataProtocol:
     async def enter_passive_mode(self):
         if self.server is None:
             self.server = await self._create_server()
-        return get_server_address_and_port(self.server)
+        return get_server_endpoint(self.server)
 
     async def _create_server(self):
         port = self.port
